@@ -42,7 +42,8 @@
 
 typedef Collection Aliases;
 
-typedef struct {
+typedef struct
+{
 	char *comment_begin;
 	char *comment_end;
 
@@ -184,6 +185,9 @@ typedef struct {
 	char *outline_begin;
 	char *outline_end;
 
+	char *all_caps_begin;
+	char *all_caps_end;
+
 	char *small_caps_begin;
 	char *small_caps_end;
 
@@ -216,7 +220,8 @@ typedef struct {
 	/* XX These should really be replaced by references
 	 * to one of the charsets.
 	 */
-	struct {
+	struct
+	{
 		char *bullet;
 		char *left_quote;
 		char *right_quote;
@@ -244,17 +249,17 @@ typedef struct {
 OutputPersonality;
 
 
-extern OutputPersonality* op_create(void);
-extern void op_free (OutputPersonality*);
-extern char *op_translate_char (OutputPersonality *op, char *encoding, int ch);
-extern char *op_translate_buffer(OutputPersonality *op, char *buffer, 
+extern OutputPersonality *op_create(void);
+extern void op_free(OutputPersonality *);
+extern const char *op_translate_char(OutputPersonality *op, char *encoding, int ch);
+extern char *op_translate_buffer(OutputPersonality *op, char *buffer,
                                  int bytescnt);
 
-extern void op_begin_std_fontsize (OutputPersonality*, int);
-extern void op_end_std_fontsize (OutputPersonality*, int);
+extern void op_begin_std_fontsize(OutputPersonality *, int);
+extern void op_end_std_fontsize(OutputPersonality *, int);
 
 void add_alias(OutputPersonality *op, int nr, char *text);
-char *get_alias(OutputPersonality *op, int nr);
+const char *get_alias(OutputPersonality *op, int nr);
 
 
 #endif /* _OUTPUT_H_INCLUDED_ */
